==> dl.php?src=linea21_1_6.zip: linea21/languages/it/lang_user.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['user']['section'] = "utenti";

/*	nommage des modules
 *  	*/
$lang['user']['name']='utente';
$lang['user']['confirm_add'] = "Aggiunta di un utente avvenuta con successo\n";
$lang['user']['confirm_mod'] = "Modifica dell'utente avvenuta con successo\n";
$lang['user']['confirm_modpass'] = "Generazione di una nuova password per l'utente avvenuta con successo\n";
$lang['user']['confirm_sup'] ="Eliminazione dell'utente avvenuta con successo\n";
$lang['user']['confirm_changetype']="Modifica del tipo di utente avvenuta con successo\n";
$lang['user']['confirm_public'] = 'Creazione del tuo accuont avvenuta con successo. La password ti è stata trasmessa via email.';
$lang['user']['confirm_delavatar'] = "Avatar successfully deleted"; // @todo translation


/*	nommage rubrique module
 *  	*/
$lang['user']['add']= 'Aggiunta di un '.$lang['user']['name'];
$lang['user']['mod']= 'Modifica di un '.$lang['user']['name'];
$lang['user']['sup']= 'Eliminazione di '.$lang['user']['name'];
$lang['user']['det']= 'Dettagli di'.$lang['user']['name'];
$lang['user']['list']= 'Consultazione dei utenti';


$lang['user']['h1_public_comment_insc']='L\'iscrizione ti permette di partecipare ai differenti gruppi di lavoro. In seguito alla tua registrazione, riceverai via mail una password che potrai successivamente modificare.';
$lang['user']['h1_public_comment_auth']='Autenticati al fine di accedere ai gruppi di lavoro e di avere accesso alle tue informazioni personali in modifica.';
$lang['user']['h1_public_comment']='Presentati agli altri. Il tuo profilo utente è a tua disposizione per descriverti e permettere così alla comunità di conoscerti meglio.';

/*	nommage public
 *  	*/

$lang['user']['p_mod']= 'Modifica del tuo profilo utente';
$lang['user']['forgot_pass']= 'Forgot your password'; // @todo translation
$lang['user']['p_mod_table_summary']='Modulo di modifica del tuo profilo utente';
$lang['user']['info_mail']= 'Se cambi la tua email, ti sarà attribuita una nuova password tramite una email di conferma spedita al tuo nuovo indirizzo.';
$lang['user']['info_password']=  'Riempi i campi seguenti UNICAMENTE se desideri modificare la password !';
$lang['user']['p_new_password']=  'Nuova password';
$lang['user']['p_new_password_confirm']=  'password (conferma) ';
$lang['user']['new_password_confirmation']=  'A new password has been sent to you by email.'; // @todo translation
$lang['user']['p_confirm_mod'] = "Modifica del tuo profilo avvenuta con successo";
$lang['user']['p_confirm_back'] = "Clicca qui per ritornare alla home page";
$lang['user']['info_inscription'] = "Non sei ancora iscritto ?";
$lang['user']['info_inscription2'] = "Clicca qui per creare il tuo account";
$lang['user']['info_inscription3'] = "L'iscrizione ti permette di partecipare ai differenti gruppi di lavoro.";
//$lang['user']['info_inscription4'] = "Suite à votre enregistrement, vous recevrez par email, un mot de passe que vous pourrez changer ultérieurement";
$lang['user']['info_inscription5'] = "ATTENZIONE : Devi tassativamente accettare i cookies per accedere alle funzioni utente !";

/*	password strength javascript test
 *  	*/
$lang['password_strength']['too_short']='At least %s characters please!'; // @todo translation
$lang['password_strength']['novalue']='No value'; // @todo translation
$lang['password_strength']['weak']='Weak'; // @todo translation
$lang['password_strength']['average']='Average'; // @todo translation
$lang['password_strength']['strong']='Strong'; // @todo translation
$lang['password_strength']['secure']='Secure'; // @todo translation

/*	nommage rubrique add / mod /det
 *  	*/
$lang['user']['add_title']='Inserimento delle informazioni del nuovo '.$lang['user']['name'];
$lang['user']['mod_title']='Modifica delle informazioni del '.$lang['user']['name'];


/*	check integrité des données
 *  	*/
$lang['user']['login_used'] = 'Questo nome utente è già in uso. Per favore, scegline un altro';
$lang['user']['login_tooshort'] = 'Il tuo nome utente non è abbastanza lungo (minimo 5 caratteri).';
$lang['user']['login_toolong'] = 'Il tuo nome utente è troppo lungo (massimo 20 caratteri).';
$lang['user']['login_prohibited'] = 'Il tuo nome utente contiene dei caratteri non autorizzati.';
$lang['user']['pass_tooshort'] = 'La tua password non è abbastanza lunga (minimo %s caratteri).';
$lang['user']['pass_toolong'] = 'La tua password è troppo lunga (massimo 15 caratteri).';
$lang['user']['pass_not_same'] = 'I valori inseriti per la nuova password non corrispondono.';
$lang['user']['invalid_mail'] = 'L\'email inserita non è valida';


/*	nommage élément rubrique
 *  	*/
$lang['user']['type']='Tipo di'.$lang['user']['name'];
$lang['user']['type_simple']=$lang['user']['name'].' semplice';
$lang['user']['type_privilege']=$lang['user']['name'].' privilegiato';
$lang['user']['type_admin']='amministratore';
$lang['user']['pseudo']='nickname (login)';
$lang['user']['email']='email '.$lang['user']['name'];
$lang['user']['first_name']='nome';
$lang['user']['last_name']='cognome';
$lang['user']['workgroups']='Workgroups subscription'; // @todo translation
$lang['user']['profile']='Profilo di'.$lang['user']['name'];



$lang['user']['rights']='Diritti per moduli';
$lang['user']['set_rights']='Attribuzione dei diritti per moduli';
$lang['user']['update_rights']='Modifica dei diritti per moduli';
$lang['user']['norights']='nessun diritto';
$lang['user']['redactorrights']='redattore';
$lang['user']['animatorrights']='moderatore';
$lang['user']['adminrights']='amministratore';
$lang['user']['managerrights']='manager';
$lang['user']['login']='username';
$lang['user']['password']='password';
$lang['user']['email']='email';
$lang['user']['groupe']='gruppo';
$lang['user']['date_record']='data di registrazione';
$lang['user']['actions']='azioni';


$lang['user']['email_display']='Email Pubblica';
$lang['user']['city']='Città';
$lang['user']['birthdate']='Data di nascita';
$lang['user']['leisures']='Tempo libero';
$lang['user']['job']='Occupazione/mestiere';
$lang['user']['avatar']='Avatar';
$lang['user']['current_avatar']='Avatar attuale';
$lang['user']['delete_avatar']='Delete current avatar'; // @todo translation
$lang['user']['quotation']='Citazione';
$lang['user']['latest_con']='Latest connexion'; // @todo translation
$lang['user']['signature']='Firma';
// $lang['user']['comment']="Commentaire lié à cet ".$lang['user']['name'];

$lang['user']['preferences']='Personal settings'; // @todo translation
$lang['user']['my_workgroups']='My workgroups'; // @todo translation
$lang['user']['workgroups_notification']='By enabling notification you will receive an email whenever an event will take place into workgroups you\'re involved in. You can set up notfication options for any of them.'; // @todo translation
$lang['user']['notify_file']='Notification - New file'; // @todo translation
$lang['user']['notify_topic']='Notification - New topic'; // @todo translation
$lang['user']['notify_post']='Notification - New post'; // @todo translation
$lang['user']['workgroups_label']='Workgroup'; // @todo translation
$lang['user']['notify_changes_success']='Notification settings successfully updated.'; // @todo translation

/*	nommage quickbox
 *  	*/
$lang['user']['qb_titleadd']=' ultime aggiunte effettuate';
$lang['user']['qb_titlemod']=' ultime modifiche effettuate';
$lang['user']['qb_titlesup']=' ultime eliminazioni effettuate';


$lang['user']['new_password']='Attribuire una nuova password';
$lang['user']['2ADMIN_USER']='Trasformare questo utente in amministratore';
$lang['user']['2SIMPLE_USER']='Trasformare questo utente in utente standard';

/*	divers
 *  	*/
$lang['user']['selectgroup']='-- per gruppo --';
$lang['user']['alphabetical']=' [A-Z] ';
$lang['user']['nb_total']='utenti sono iscritti nel data base.';
$lang['user']['statut_filter']='Visualizzare per status';
$lang['user']['all']='Visualizzare la lista completa';
$lang['user']['noresult']='Nessun utente corrisponde a questo criterio di selezione ';


/*	messages
 *  	*/
$lang['user']['admin_type_info']='L\'utente corrente è un amministratore dell\'applicazione. I suoi diritti non sono rettificabili prima della modifica del tipo di utente';



/*	rubrique d'aide

*  	*/
$lang['user']['help_add1']='Per aggiungere un utente, devi inserire il suo nome e la sua email nel modulo qui sotto.';
$lang['user']['help_add2']='Se desideri creare un utente di tipo \'privilegiato\', gli devi attribuire dei diritti sui differenti moduli';
$lang['user']['help_add3']='Dopo aver convalidato il modulo di aggiunta, controlla le informazioni inserite nel riepilogo';
$lang['user']['help_add4']='Se il riepilogo non ti soddisfa, puoi cliccare su \'modifica i parametri\' per modificare nuovamente i dati';
$lang['user']['help_add5']='Una password generata in modo casuale sarà automaticamente inviata al nuovo utente al momento della sua creazione';


$lang['user']['help_list1']='Per visualizzare il dettaglio di un utente, clicca sul ome del medesimo';
$lang['user']['help_list2']='Puoi eliminare un utente cliccando sull\'icona di eliminazione associata';
$lang['user']['help_list3']='Puoi modificare un utente cliccando sull\'icona di modifica associata';
$lang['user']['help_list4']='Puoi utilizzare i filtri \'per gruppo\' per visualizzare unicamente il tipo di utente desiderato';
$lang['user']['help_list5']='Puoi utilizzare il filtro \'alfabetico\' per restringere la visualizzazione degli utenti';
$lang['user']['help_list6']='Per aggiungere un utente, clicca sul link  \'aggiunta di un utente\' nella barra degli strumenti';
$lang['user']['help_list7']='Puoi effettuare una ricerca avanzata in ogni momento cliccando su \'ricerca\'';


$lang['user']['help_mod1']='Puoi modificare ciascuno dei parametri nel modulo qui sotto';
$lang['user']['help_mod2']='Dopo aver convalidato il modulo di modifica, controlla le informazioni inserite nel riepilogo';
$lang['user']['help_mod3']='Se il riepilogo non ti soddisfa, puoi cliccare su \'modifica i parametri\' per modificare nuovamente i dati';


$lang['user']['help_det1']='Puoi eliminare questo utente cliccando sull\'icona di eliminazione associata';
$lang['user']['help_det2']='Puoi modificare le informazioni riguardanti questo utente cliccando sull\'icona di modifica associata';

$lang['user']['help_sup1']='Se non desideri confermare l\'eliminazione dell\'utente in corso, clicca su \'Annulla\'.';



/*	mail
 **/
$lang['user']['mail_add_subject']='conferma della creazione del tuo account su';
$lang['user']['mail_add_body1']='Il tuo account è stato creato con successo.';
$lang['user']['mail_add_body2']='da questo momento ti puoi loggare. Ti ricordiamo i tuoi parametri di connessione.';
$lang['user']['mail_head']="Raggiungici su";
$lang['user']['mail_bottom']="Per qualsiasi domanda relativa al tuo accesso";

$lang['user']['mail_changemail_subject']='conferma del cambiamento della coppia email/password';
$lang['user']['mail_changemail_body1']='Hai ricevuto questa email perché hai cambiato il tuo indirizzo email. Per sicurezza ti attribuiamo una nuova password.';
$lang['user']['mail_changemail_body2']='Sappi che ti è possibile cambiare la password entrando nella gestione del tuo \'profilo utente\'.';

$lang['user']['mail_changepass_subject']='Nuova password';
$lang['user']['mail_changepass_body1']='Hai ricevuto questa email perché hai cambiato la password o perché te ne è stata attribuita una nuova.';
$lang['user']['mail_changepass_body2']='Sappi che ti è possibile cambiare password entrando nella gestione del tuo \'profilo utente\'.';

$lang['user']['mail_forgotpass_subject']='Forgotten password'; // @todo translation
$lang['user']['mail_forgotpass_body1']='You ask for a new password. Please click the following url (or copy-paste it into your browser) to process.' ; // @todo translation
$lang['user']['mail_forgotpass_body2']='If you did not ask for a new password, just ignore that email.'; // @todo translation
?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/it/lang_user.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['user']['section'] = "utenti";

/*	nommage des modules
 *  	*/
$lang['user']['name']='utente';
$lang['user']['confirm_add'] = "Aggiunta di un utente avvenuta con successo\n";
$lang['user']['confirm_mod'] = "Modifica dell'utente avvenuta con successo\n";
$lang['user']['confirm_modpass'] = "Generazione di una nuova password per l'utente avvenuta con successo\n";
$lang['user']['confirm_sup'] ="Eliminazione dell'utente avvenuta con successo\n";
$lang['user']['confirm_changetype']="Modifica del tipo di utente avvenuta con successo\n";
$lang['user']['confirm_public'] = 'Creazione del tuo accuont avvenuta con successo. La password ti è stata trasmessa via email.';
$lang['user']['confirm_delavatar'] = "Avatar successfully deleted"; // @todo translation


/*	nommage rubrique module
 *  	*/
$lang['user']['add']= 'Aggiunta di un '.$lang['user']['name'];
$lang['user']['mod']= 'Modifica di un '.$lang['user']['name'];
$lang['user']['sup']= 'Eliminazione di '.$lang['user']['name'];
$lang['user']['det']= 'Dettagli di'.$lang['user']['name'];
$lang['user']['list']= 'Consultazione dei utenti';


$lang['user']['h1_public_comment_insc']='L\'iscrizione ti permette di partecipare ai differenti gruppi di lavoro. In seguito alla tua registrazione, riceverai via mail una password che potrai successivamente modificare.';
$lang['user']['h1_public_comment_auth']='Autenticati al fine di accedere ai gruppi di lavoro e di avere accesso alle tue informazioni personali in modifica.';
$lang['user']['h1_public_comment']='Presentati agli altri. Il tuo profilo utente è a tua disposizione per descriverti e permettere così alla comunità di conoscerti meglio.';

/*	nommage public
 *  	*/

$lang['user']['p_mod']= 'Modifica del tuo profilo utente';
$lang['user']['forgot_pass']= 'Forgot your password'; // @todo translation
$lang['user']['p_mod_table_summary']='Modulo di modifica del tuo profilo utente';
$lang['user']['info_mail']= 'Se cambi la tua email, ti sarà attribuita una nuova password tramite una email di conferma spedita al tuo nuovo indirizzo.';
$lang['user']['info_password']=  'Riempi i campi seguenti UNICAMENTE se desideri modificare la password !';
$lang['user']['p_new_password']=  'Nuova password';
$lang['user']['p_new_password_confirm']=  'password (conferma) ';
$lang['user']['new_password_confirmation']=  'A new password has been sent to you by email.'; // @todo translation
$lang['user']['p_confirm_mod'] = "Modifica del tuo profilo avvenuta con successo";
$lang['user']['p_confirm_back'] = "Clicca qui per ritornare alla home page";
$lang['user']['info_inscription'] = "Non sei ancora iscritto ?";
$lang['user']['info_inscription2'] = "Clicca qui per creare il tuo account";
$lang['user']['info_inscription3'] = "L'iscrizione ti permette di partecipare ai differenti gruppi di lavoro.";
//$lang['user']['info_inscription4'] = "Suite à votre enregistrement, vous recevrez par email, un mot de passe que vous pourrez changer ultérieurement";

/*	password strength javascript test
 *  	*/
$lang['password_strength']['too_short']='At least %s characters please!'; // @todo translation
$lang['password_strength']['novalue']='No value'; // @todo translation
$lang['password_strength']['weak']='Weak'; // @todo translation
$lang['password_strength']['average']='Average'; // @todo translation
$lang['password_strength']['strong']='Strong'; // @todo translation
$lang['password_strength']['secure']='Secure'; // @todo translation

/*	nommage rubrique add / mod /det
 *  	*/
$lang['user']['add_title']='Inserimento delle informazioni del nuovo '.$lang['user']['name'];
$lang['user']['mod_title']='Modifica delle informazioni del '.$lang['user']['name'];


/*	check integrité des données
 *  	*/
$lang['user']['login_used'] = 'Questo nome utente è già in uso. Per favore, scegline un altro';
$lang['user']['login_tooshort'] = 'Il tuo nome utente non è abbastanza lungo (minimo 5 caratteri).';
$lang['user']['login_toolong'] = 'Il tuo nome utente è troppo lungo (massimo 50 caratteri).';
$lang['user']['login_prohibited'] = 'Il tuo nome utente contiene dei caratteri non autorizzati.';
$lang['user']['pass_tooshort'] = 'La tua password non è abbastanza lunga (minimo %s caratteri).';
$lang['user']['pass_toolong'] = 'La tua password è troppo lunga (massimo 15 caratteri).';
$lang['user']['pass_not_same'] = 'I valori inseriti per la nuova password non corrispondono.';
$lang['user']['invalid_mail'] = 'L\'email inserita non è valida';


/*	nommage élément rubrique
 *  	*/
$lang['user']['type']='Tipo di'.$lang['user']['name'];
$lang['user']['type_simple']=$lang['user']['name'].' semplice';
$lang['user']['type_privilege']=$lang['user']['name'].' privilegiato';
$lang['user']['type_admin']='amministratore';
$lang['user']['pseudo']='nickname (login)';
$lang['user']['email']='email '.$lang['user']['name'];
$lang['user']['first_name']='nome';
$lang['user']['last_name']='cognome';
$lang['user']['workgroups']='Workgroups subscription'; // @todo translation
$lang['user']['profile']='Profilo di'.$lang['user']['name'];



$lang['user']['rights']='Diritti per moduli';
$lang['user']['set_rights']='Attribuzione dei diritti per moduli';
$lang['user']['update_rights']='Modifica dei diritti per moduli';
$lang['user']['norights']='nessun diritto';
$lang['user']['redactorrights']='redattore';
$lang['user']['animatorrights']='moderatore';
$lang['user']['adminrights']='amministratore';
$lang['user']['managerrights']='manager';
$lang['user']['login']='username';
$lang['user']['previous_logins']='previous login(s)';  // @todo translation
$lang['user']['password']='password';
$lang['user']['email']='email';
$lang['user']['groupe']='gruppo';
$lang['user']['date_record']='data di registrazione';
$lang['user']['actions']='azioni';


$lang['user']['email_display']='Email Pubblica';
$lang['user']['city']='Città';
$lang['user']['birthdate']='Data di nascita';
$lang['user']['leisures']='Tempo libero';
$lang['user']['job']='Occupazione/mestiere';
$lang['user']['avatar']='Avatar';
$lang['user']['current_avatar']='Avatar attuale';
$lang['user']['delete_avatar']='Delete current avatar'; // @todo translation
$lang['user']['quotation']='Citazione';
$lang['user']['latest_con']='Latest connexion'; // @todo translation
$lang['user']['signature']='Firma';
// $lang['user']['comment']="Commentaire lié à cet ".$lang['user']['name'];

$lang['user']['preferences']='Personal settings'; // @todo translation
$lang['user']['my_workgroups']='My workgroups'; // @todo translation
$lang['user']['workgroups_notification']='By enabling notification you will receive an email whenever an event will take place into workgroups you\'re involved in. You can set up notfication options for any of them.'; // @todo translation
$lang['user']['notify_file']='Notification - New file'; // @todo translation
$lang['user']['notify_topic']='Notification - New topic'; // @todo translation
$lang['user']['notify_post']='Notification - New post'; // @todo translation
$lang['user']['workgroups_label']='Workgroup'; // @todo translation
$lang['user']['notify_changes_success']='Notification settings successfully updated.'; // @todo translation
$lang['user']['change_login']='change login'; // @todo translation
$lang['user']['change_login_desc']='%s change(s) done on %s allowed'; // @todo translation
$lang['user']['change_login_limit_done']='change(s) done : %s/%s'; // @todo translation
$lang['user']['change_login_allowed']='You are allowed to change your login'; // @todo translation
$lang['user']['change_login_limit_reached']='You are not allowed to change your login'; // @todo translation
$lang['user']['newsletter_subscription_info']='By registering on our website, you accept to subscribe automatically to our newsletter. You would be able to unsubscribe newsletter at any time, after registration.'; // @todo translation

/*	nommage quickbox
 *  	*/
$lang['user']['qb_titleadd']=' ultime aggiunte effettuate';
$lang['user']['qb_titlemod']=' ultime modifiche effettuate';
$lang['user']['qb_titlesup']=' ultime eliminazioni effettuate';

$lang['user']['ldap_password']='your usual password'; // @todo translation
$lang['user']['new_password']='Attribuire una nuova password';
$lang['user']['2ADMIN_USER']='Trasformare questo utente in amministratore';
$lang['user']['2SIMPLE_USER']='Trasformare questo utente in utente standard';

/*	divers
 *  	*/
$lang['user']['selectgroup']='-- per gruppo --';
$lang['user']['alphabetical']=' [A-Z] ';
$lang['user']['nb_total']='utenti sono iscritti nel data base.';
$lang['user']['statut_filter']='Visualizzare per status';
$lang['user']['all']='Visualizzare la lista completa';
$lang['user']['noresult']='Nessun utente corrisponde a questo criterio di selezione ';


/*	messages
 *  	*/
$lang['user']['admin_type_info']='L\'utente corrente è un amministratore dell\'applicazione. I suoi diritti non sono rettificabili prima della modifica del tipo di utente';



/*	rubrique d'aide

*  	*/
$lang['user']['help_add1']='Per aggiungere un utente, devi inserire il suo nome e la sua email nel modulo qui sotto.';
$lang['user']['help_add2']='Se desideri creare un utente di tipo \'privilegiato\', gli devi attribuire dei diritti sui differenti moduli';
$lang['user']['help_add3']='Dopo aver convalidato il modulo di aggiunta, controlla le informazioni inserite nel riepilogo';
$lang['user']['help_add4']='Se il riepilogo non ti soddisfa, puoi cliccare su \'modifica i parametri\' per modificare nuovamente i dati';
$lang['user']['help_add5']='Una password generata in modo casuale sarà automaticamente inviata al nuovo utente al momento della sua creazione';


$lang['user']['help_list1']='Per visualizzare il dettaglio di un utente, clicca sul ome del medesimo';
$lang['user']['help_list2']='Puoi eliminare un utente cliccando sull\'icona di eliminazione associata';
$lang['user']['help_list3']='Puoi modificare un utente cliccando sull\'icona di modifica associata';
$lang['user']['help_list4']='Puoi utilizzare i filtri \'per gruppo\' per visualizzare unicamente il tipo di utente desiderato';
$lang['user']['help_list5']='Puoi utilizzare il filtro \'alfabetico\' per restringere la visualizzazione degli utenti';
$lang['user']['help_list6']='Per aggiungere un utente, clicca sul link  \'aggiunta di un utente\' nella barra degli strumenti';
$lang['user']['help_list7']='Puoi effettuare una ricerca avanzata in ogni momento cliccando su \'ricerca\'';


$lang['user']['help_mod1']='Puoi modificare ciascuno dei parametri nel modulo qui sotto';
$lang['user']['help_mod2']='Dopo aver convalidato il modulo di modifica, controlla le informazioni inserite nel riepilogo';
$lang['user']['help_mod3']='Se il riepilogo non ti soddisfa, puoi cliccare su \'modifica i parametri\' per modificare nuovamente i dati';


$lang['user']['help_det1']='Puoi eliminare questo utente cliccando sull\'icona di eliminazione associata';
$lang['user']['help_det2']='Puoi modificare le informazioni riguardanti questo utente cliccando sull\'icona di modifica associata';

$lang['user']['help_sup1']='Se non desideri confermare l\'eliminazione dell\'utente in corso, clicca su \'Annulla\'.';



/*	mail
 **/
$lang['user']['mail_add_subject']='conferma della creazione del tuo account su';
$lang['user']['mail_add_body1']='Il tuo account è stato creato con successo.';
$lang['user']['mail_add_body2']='da questo momento ti puoi loggare. Ti ricordiamo i tuoi parametri di connessione.';

$lang['user']['mail_changemail_subject']='conferma del cambiamento della coppia email/password';
$lang['user']['mail_changemail_body1']='Hai ricevuto questa email perché hai cambiato il tuo indirizzo email. Per sicurezza ti attribuiamo una nuova password.';
$lang['user']['mail_changemail_body2']='Sappi che ti è possibile cambiare la password entrando nella gestione del tuo \'profilo utente\'.';

$lang['user']['mail_changelogin_subject']='New login'; // @todo translation
$lang['user']['mail_changelogin_body1']='You receive this email because you have changed your login or a new login has been attributed to you. Your new login is now : '; // @todo translation

$lang['user']['mail_changepass_subject']='Nuova password';
$lang['user']['mail_changepass_body1']='Hai ricevuto questa email perché hai cambiato la password o perché te ne è stata attribuita una nuova.';
$lang['user']['mail_changepass_body2']='Sappi che ti è possibile cambiare password entrando nella gestione del tuo \'profilo utente\'.';

$lang['user']['mail_forgotpass_subject']='Forgotten password'; // @todo translation
$lang['user']['mail_forgotpass_body1']='You ask for a new password. Please click the following url (or copy-paste it into your browser) to process.' ; // @todo translation
$lang['user']['mail_forgotpass_body2']='If you did not ask for a new password, just ignore that email.'; // @todo translation
?>
